pub enum ResponseFunctional {
MeanCurve {
outcome: VariableId,
treatment: ContinuousDomain,
},
AverageDerivative {
outcome: VariableId,
treatment: VariableId,
weighting: DerivativeWeighting,
},
PointDerivative {
outcome: VariableId,
treatment: VariableId,
at: f64,
order: u8,
scale: DerivativeScale,
},
DirectionalDerivative {
outcomes: Arc<[VariableId]>,
treatments: Arc<[VariableId]>,
at: Arc<[f64]>,
direction: Arc<[f64]>,
},
Jacobian {
outcomes: Arc<[VariableId]>,
treatments: Arc<[VariableId]>,
at: Arc<[f64]>,
scale: DerivativeScale,
},
InterventionResponse {
outcome: VariableId,
interventions: Arc<[Intervention]>,
},
}Expand description
A response functional, distinct from the estimator used to learn it.
Variants
MeanCurve
a -> E[Y | do(A=a)].
AverageDerivative
Scalar weighted average derivative effect.
Fields

outcome: VariableIdOutcome.

treatment: VariableIdTreatment.

weighting: DerivativeWeightingTarget weighting law.
PointDerivative
Local derivative of a response representation.
Fields

outcome: VariableIdOutcome.

treatment: VariableIdTreatment.

scale: DerivativeScaleReporting scale.
DirectionalDerivative
Directional derivative for a vector intervention.
Jacobian
Low-dimensional response Jacobian.
Fields

outcomes: Arc<[VariableId]>Outcomes.

treatments: Arc<[VariableId]>Treatments.

scale: DerivativeScaleReporting scale.
InterventionResponse
Mean response under an existing intervention or joint intervention.